import { useState } from 'react';

type ValidationRules<T> = {
  [K in keyof T]?: (value: T[K]) => boolean;
};

export const useFormValidation = <T>(
  initialState: T,
  validationRules: ValidationRules<T>
) => {
  const [formData, setFormData] = useState<T>(initialState);
  const [errors, setErrors] = useState<Record<keyof T, string>>({} as Record<keyof T, string>);

  const validateForm = () => {
    const newErrors = {} as Record<keyof T, string>;
    for (const key in formData) {
      if (Object.prototype.hasOwnProperty.call(formData, key)) {
        if (validationRules[key as keyof T] && !validationRules[key as keyof T]!(formData[key as keyof T])) {
          newErrors[key as keyof T] = `Invalid ${String(key)}`;
        }
      }
    }
    setErrors(newErrors);

    return Object.keys(newErrors).length === 0
  };

  const handleChange = (key: keyof T, value: T[keyof T]) => {
    setFormData((prevData) => ({
      ...prevData,
      [key]: value,
    }));

    if (validationRules[key] && !validationRules[key]!(value)) {
      setErrors((prevErrors) => ({
        ...prevErrors,
        [key]: `Invalid ${String(key)}`,
      }));
    } else {
      setErrors((prevErrors) => ({
        ...prevErrors,
        [key]: '',
      }));
    }
  };

  return { formData, errors, handleChange, validateForm };
}


